@@ -4,7 +4,6 @@ from plone.app.registry.browser.controlpanel import RegistryEditForm
 from rer.solrpush import _
 from rer.solrpush.interfaces import IElevateSettings
 from z3c.form import field
-from collective.z3cform.datagridfield import DataGridFieldFactory
 
 
 class ElevateSettingsEditForm(RegistryEditForm):
@@ -16,7 +15,6 @@ class ElevateSettingsEditForm(RegistryEditForm):
     )
 
     fields = field.Fields(IElevateSettings)
-    fields["elevate_schema"].widgetFactory = DataGridFieldFactory
 
 
 class ElevateSettingsView(ControlPanelFormWrapper):
