@@ -24,3 +24,8 @@ def to_1200(context):
     setup_tool.runImportStepFromProfile(default_profile, "plone.app.registry")
     setup_tool.runImportStepFromProfile(default_profile, "rolemap")
     setup_tool.runImportStepFromProfile(default_profile, "controlpanel")
+
+
+def to_1300(context):
+    setup_tool = api.portal.get_tool(name="portal_setup")
+    setup_tool.runAllImportStepsFromProfile("profile-rer.solrpush:to_1300")
